<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grades</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
